package simplebug;

import gnu.io.CommPort;
import gnu.io.CommPortIdentifier;
import gnu.io.NoSuchPortException;
import gnu.io.SerialPort;
import java.io.InputStream;
import java.io.OutputStream;

/**
 *
 * @author matthew stevenson
 */
public class Main {

    public static void main(String[] args) {
        try{
            CommPortIdentifier portIdentifier;
            try{
                portIdentifier = CommPortIdentifier.getPortIdentifier("/dev/ttyUSB0");
            }catch(NoSuchPortException ex){
                throw new IllegalArgumentException("Port not found.", ex);
            }
            if(portIdentifier.isCurrentlyOwned()){
                throw new IllegalAccessError("Port in use");
            }
            CommPort commPort = portIdentifier.open(Main.class.getName(),2000);
            if(!(commPort instanceof SerialPort)){
                throw new IllegalArgumentException("Port is not a Serial Port.");
            }
            SerialPort myPort = (SerialPort)commPort;
            myPort.setSerialPortParams(2400,SerialPort.DATABITS_8,SerialPort.STOPBITS_1,SerialPort.PARITY_NONE);
            InputStream myPortReader = myPort.getInputStream();
            OutputStream myPortWriter = myPort.getOutputStream();
            Thread.sleep(2000);

            byte id = 1;

            /*******************************************************************
             * Test 85
             ******************************************************************/
            System.out.println("Sending to low 84");
            myPortWriter.write(new byte[]{'!','S','C',id,0,84,1,(byte)13});
            myPortWriter.write(new byte[]{'!','S','C','R','S','P', id,(byte)13});
            myPortWriter.flush();
            Thread.sleep(175);
            int n = myPortReader.available();
            System.out.println("Expect 3 bytes, got " + n);
            myPortReader.read(new byte[n]);

            System.out.println("Sending to low 85");
            myPortWriter.write(new byte[]{'!','S','C',id,0,85,1,13});
            myPortWriter.write(new byte[]{'!','S','C','R','S','P', id,(byte)13});
            myPortWriter.flush();
            Thread.sleep(175);
            n = myPortReader.available();
            System.out.println("Expect 4 bytes, got " + n);
            myPortReader.read(new byte[n]);
            
            /*******************************************************************
             * Test 33
             ******************************************************************/
            byte[] bytes = new byte[3];
            System.out.println("Sending to low 32");
            myPortWriter.write(new byte[]{'!','S','C',id,0,32,1,13});
            myPortWriter.write(new byte[]{'!','S','C','R','S','P', id,13});
            myPortWriter.flush();
            Thread.sleep(175);
            myPortReader.read(bytes);
            System.out.println("Expect low 32, got " + bytes[2]);

            System.out.println("Sending to low 33");
            myPortWriter.write(new byte[]{'!','S','C',id,0,33,1,13});
            myPortWriter.write(new byte[]{'!','S','C','R','S','P', id,13});
            myPortWriter.flush();
            Thread.sleep(175);
            myPortReader.read(bytes);
            System.out.println("Expect low 33, got " + bytes[2]);

            System.out.println("Sending to low 50");
            myPortWriter.write(new byte[]{'!','S','C',id,0,50,1,13});
            myPortWriter.write(new byte[]{'!','S','C','R','S','P', id,13});
            myPortWriter.flush();
            Thread.sleep(175);
            myPortReader.read(bytes);
            System.out.println("Expect low 33, got " + bytes[2]);

            myPortReader.close();
            myPortWriter.close();
            myPort.close();
        }catch(Throwable t){
            t.printStackTrace();
        }
        System.exit(0);
    }

}
